==> jc-1.4.0.tar.gz: java/lang/ThreadDeath.h <==
// public class java.lang.ThreadDeath

// class file dependencies
// @dep_class 308333d803f5ab9f java_lang_Error
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class fe7096144692ae30 java_lang_ThreadDeath
// @dep_class 3be5c3c4fdd59a1e java_lang_Throwable

// header file dependencies
// @dep_header java_lang_Error

#include "java/lang/Error.h"

#ifndef _JC_java_lang_ThreadDeath_H_
#define _JC_java_lang_ThreadDeath_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_java_lang_ThreadDeath$sub_refs	_jc_java_lang_ThreadDeath$sub_refs;
typedef struct _jc_java_lang_ThreadDeath$sub_nonrefs	_jc_java_lang_ThreadDeath$sub_nonrefs;
typedef struct _jc_java_lang_ThreadDeath$refs	_jc_java_lang_ThreadDeath$refs;
typedef struct _jc_java_lang_ThreadDeath$nonrefs	_jc_java_lang_ThreadDeath$nonrefs;
typedef struct _jc_java_lang_ThreadDeath$object	_jc_java_lang_ThreadDeath$object;

typedef struct _jc_java_lang_ThreadDeath$fields_struct	_jc_java_lang_ThreadDeath$fields_struct;
typedef const struct _jc_java_lang_ThreadDeath$vmethods	_jc_java_lang_ThreadDeath$vmethods;
typedef const struct _jc_java_lang_ThreadDeath$vtable	_jc_java_lang_ThreadDeath$vtable;
typedef const struct _jc_java_lang_ThreadDeath$vtype	_jc_java_lang_ThreadDeath$vtype;

// Class fields structure
struct _jc_java_lang_ThreadDeath$fields_struct {
	jlong	serialVersionUID;
};
extern _jc_java_lang_ThreadDeath$fields_struct _jc_java_lang_ThreadDeath$class_fields;

// Constructors
extern void _jc_java_lang_ThreadDeath$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_java_lang_ThreadDeath$object *);

// Virtual methods structure
struct _jc_java_lang_ThreadDeath$vmethods {
};

// Vtable
struct _jc_java_lang_ThreadDeath$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_lang_Throwable$vmethods	java_lang_Throwable;
	_jc_java_lang_Error$vmethods	java_lang_Error;
	_jc_java_lang_ThreadDeath$vmethods	java_lang_ThreadDeath;
};

// Vtype
struct _jc_java_lang_ThreadDeath$vtype {
	_jc_type			type;
	_jc_java_lang_ThreadDeath$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_lang_ThreadDeath$sub_refs {
};

// Reference instance fields (object)
struct _jc_java_lang_ThreadDeath$refs {
    _jc_java_lang_ThreadDeath$sub_refs	java_lang_ThreadDeath;
    _jc_java_lang_Error$sub_refs	java_lang_Error;
    _jc_java_lang_Throwable$sub_refs	java_lang_Throwable;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_lang_ThreadDeath$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_lang_ThreadDeath$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_lang_Throwable$sub_nonrefs	java_lang_Throwable;
    _jc_java_lang_Error$sub_nonrefs	java_lang_Error;
    _jc_java_lang_ThreadDeath$sub_nonrefs	java_lang_ThreadDeath;
};

// Object instance structure
struct _jc_java_lang_ThreadDeath$object {
	_jc_java_lang_ThreadDeath$refs	refs[0];
	_jc_word		lockword;
	_jc_java_lang_ThreadDeath$vtype	*vtype;
	_jc_java_lang_ThreadDeath$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_lang_ThreadDeath$vtype _jc_java_lang_ThreadDeath$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_lang_ThreadDeath, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_lang_ThreadDeath$class_object;

#endif	/* _JC_java_lang_ThreadDeath_H_ */

==> jc-1.4.6.tar.gz: java/lang/ThreadDeath.h <==
// public class java.lang.ThreadDeath

// class file dependencies
// @dep_class 308333d803f5ab9f java_lang_Error
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class fe7096144692ae30 java_lang_ThreadDeath
// @dep_class 3be5c3c4fdd59a1e java_lang_Throwable

// header file dependencies
// @dep_header java_lang_Error

#include "java/lang/Error.h"

#ifndef _JC_java_lang_ThreadDeath_H_
#define _JC_java_lang_ThreadDeath_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_java_lang_ThreadDeath$sub_refs	_jc_java_lang_ThreadDeath$sub_refs;
typedef struct _jc_java_lang_ThreadDeath$sub_nonrefs	_jc_java_lang_ThreadDeath$sub_nonrefs;
typedef struct _jc_java_lang_ThreadDeath$refs	_jc_java_lang_ThreadDeath$refs;
typedef struct _jc_java_lang_ThreadDeath$nonrefs	_jc_java_lang_ThreadDeath$nonrefs;
typedef struct _jc_java_lang_ThreadDeath$object	_jc_java_lang_ThreadDeath$object;

typedef struct _jc_java_lang_ThreadDeath$fields_struct	_jc_java_lang_ThreadDeath$fields_struct;
typedef const struct _jc_java_lang_ThreadDeath$vmethods	_jc_java_lang_ThreadDeath$vmethods;
typedef const struct _jc_java_lang_ThreadDeath$vtable	_jc_java_lang_ThreadDeath$vtable;
typedef const struct _jc_java_lang_ThreadDeath$vtype	_jc_java_lang_ThreadDeath$vtype;

// Class fields structure
struct _jc_java_lang_ThreadDeath$fields_struct {
	jlong	serialVersionUID;
};
extern _jc_java_lang_ThreadDeath$fields_struct _jc_java_lang_ThreadDeath$class_fields;

// Constructors
extern void _jc_java_lang_ThreadDeath$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_java_lang_ThreadDeath$object *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_java_lang_ThreadDeath$vmethods {
};

// Vtable
struct _jc_java_lang_ThreadDeath$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_lang_Throwable$vmethods	java_lang_Throwable;
	_jc_java_lang_Error$vmethods	java_lang_Error;
	_jc_java_lang_ThreadDeath$vmethods	java_lang_ThreadDeath;
};

// Vtype
struct _jc_java_lang_ThreadDeath$vtype {
	_jc_type			type;
	_jc_java_lang_ThreadDeath$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_lang_ThreadDeath$sub_refs {
};

// Reference instance fields (object)
struct _jc_java_lang_ThreadDeath$refs {
    _jc_java_lang_ThreadDeath$sub_refs	java_lang_ThreadDeath;
    _jc_java_lang_Error$sub_refs	java_lang_Error;
    _jc_java_lang_Throwable$sub_refs	java_lang_Throwable;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_lang_ThreadDeath$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_lang_ThreadDeath$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_lang_Throwable$sub_nonrefs	java_lang_Throwable;
    _jc_java_lang_Error$sub_nonrefs	java_lang_Error;
    _jc_java_lang_ThreadDeath$sub_nonrefs	java_lang_ThreadDeath;
};

// Object instance structure
struct _jc_java_lang_ThreadDeath$object {
	_jc_java_lang_ThreadDeath$refs	refs[0];
	_jc_word		lockword;
	_jc_java_lang_ThreadDeath$vtype	*vtype;
	_jc_java_lang_ThreadDeath$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_lang_ThreadDeath$vtype _jc_java_lang_ThreadDeath$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_lang_ThreadDeath, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_lang_ThreadDeath$class_object;

#endif	/* _JC_java_lang_ThreadDeath_H_ */
